@@ -50,7 +50,7 @@ __license__ = "GPLv2"
 __maintainer__ = "Michael G. Noll"
 __status__ = "Development"
 __url__ = "http://www.michael-noll.com/"
-__version__ = "1.5.13"
+__version__ = "1.5.14"
 
 import base64
 import cgi
@@ -765,7 +765,7 @@ class DeliciousAPI(object):
                 comment = u""
                 datas = bookmark_element.findAll("div", attrs={"class": "data"})
                 if datas:
-                    links = datas[0].findAll("a", attrs={"class": "taggedlink"})
+                    links = datas[0].findAll("a", attrs={"class": re.compile("^taggedlink\s*")})
                     if links:
                         title = links[0].contents[0].strip()
                         url = links[0]['href']
